Struct safe_app::ipc::resp::AuthGranted [−][src]
pub struct AuthGranted {
pub app_keys: AppKeys,
pub bootstrap_config: Config,
pub access_container_info: AccessContInfo,
pub access_container_entry: HashMap<String, (MDataInfo, BTreeSet<Permission>), RandomState>,
}It represents the authentication response.
Fields
app_keys: AppKeys
The access keys.
bootstrap_config: Config
The crust config. Useful to reuse bootstrap nodes and speed up access.
access_container_info: AccessContInfo
Access container info
access_container_entry: HashMap<String, (MDataInfo, BTreeSet<Permission>), RandomState>
Access container entry
Methods
impl AuthGranted[src]
impl AuthGrantedpub fn into_repr_c(self) -> Result<AuthGranted, IpcError>[src]
pub fn into_repr_c(self) -> Result<AuthGranted, IpcError>Consumes the object and returns the wrapped raw pointer
You're now responsible for freeing this memory once you're done.